
#pragma once


#include "realworld.h"


////////////////////////////////////////////////////////////
// interface functions for machine learning related problems
//


// Tuning of the hyper-parameters of a learning machine,
// namely a kernel ridge regression model with Gaussian
// kernel, trained with (batch) gradient descent.
// inputs: training hyper-parameters: regularization, kernel, sub-sampling, learning rate, number of iterations
// objectives: RMSE on a test set
//             training time (computed, not measured)
Vector kernel_ridge_regression_parameter_tuning(Vector const& x);

// Tuning of a controller of a double pole balancer.
// This is a classic test task for control algorithms.
// inputs: network weights (24 dimensional)
// objectives: balancing time,
//             applied force, time averaged
Vector neuralnet_double_pole_balancing(Vector const& x);

// Maximization of the AUC (area under curve) of a quadratic classifier,
// directly represented by the Pareto front.
// inputs: weight vector (10 dimensional)
// objectives: number of misclassified positive and negative points
Vector auc_maximization(Vector const& x);
